From 1e619a9cb01819fbdd36e7e55d499eeebb952440 Mon Sep 17 00:00:00 2001
From: Akash Mehrotra <mehrotra.akash@gmail.com>
Date: Thu, 21 Jul 2011 03:29:45 +0530
Subject: [PATCH 2/3] bugfixes to equalizer.xml

---
 modules/lua/libs/equalizer.c |  145 ++++++++++++++++++++++++++++++++----------
 1 files changed, 111 insertions(+), 34 deletions(-)

diff --git a/modules/lua/libs/equalizer.c b/modules/lua/libs/equalizer.c
index 402218f..a7122ac 100644
--- a/modules/lua/libs/equalizer.c
+++ b/modules/lua/libs/equalizer.c
@@ -36,6 +36,7 @@
 #include <vlc_aout.h>
 #include <vlc_input.h>
 #include <vlc_charset.h>
+#include <vlc_interface.h>
 
 #include <lua.h>        /* Low level lua C API */
 #include <lauxlib.h>    /* Higher level C API */
@@ -43,6 +44,7 @@
 #include "input.h"
 #include "../libs.h"
 #include "../../audio_filter/equalizer_presets.h"
+#include "../vlc.h"
 
 #if !defined WIN32
 # include <locale.h>
@@ -62,13 +64,30 @@
 static int vlclua_preamp_get( lua_State *L )
 {
     input_thread_t *p_input = vlclua_get_input_internal( L );
+    vlc_object_t *p_this = vlclua_get_this( L );
+    intf_thread_t *p_intf = ( intf_thread_t * )( p_this );
+    vlc_list_t *list;
+    list = vlc_list_children( p_this );
+    int i;
     if( !p_input )
-        return 0;
-
+    {
+        lua_pushnumber( L, config_GetFloat ( p_intf, "equalizer-preamp") );
+        for( i = 0 ; i < list->i_count ; i++ )
+            vlc_object_release( list->p_values[i].p_object );    
+        return 1;
+    }
     aout_instance_t *p_aout = input_GetAout( p_input );
     vlc_object_release( p_input );
 
     char *psz_af = var_GetNonEmptyString( p_aout, "audio-filter" );
+    if( psz_af == NULL )
+    {
+        lua_pushnumber( L, config_GetFloat ( p_intf, "equalizer-preamp") );
+        vlc_object_release( p_aout );
+        for( i = 0 ; i < list->i_count ; i++ )
+            vlc_object_release( list->p_values[i].p_object );
+        return 1;
+    }
     if( strstr ( psz_af, "equalizer" ) == NULL )
     {
         free( psz_af );
@@ -76,9 +95,10 @@ static int vlclua_preamp_get( lua_State *L )
         return 0;
     }
     free( psz_af );
-
     lua_pushnumber( L, var_GetFloat( p_aout, "equalizer-preamp") );
     vlc_object_release( p_aout );
+    for( i = 0 ; i < list->i_count ; i++ )
+        vlc_object_release( list->p_values[i].p_object );
     return 1;
 }
 
@@ -98,6 +118,11 @@ static int vlclua_preamp_set( lua_State *L )
         return 0;
 
     char *psz_af = var_GetNonEmptyString( p_aout, "audio-filter" );
+    if( psz_af == NULL )
+    {
+        vlc_object_release( p_aout );
+        return 0;
+    }
     if( strstr ( psz_af, "equalizer" ) == NULL )
     {
         free( psz_af );
@@ -128,52 +153,92 @@ Band 9: 16 kHz
 /*****************************************************************************
 * Get the equalizer level for the specified band
 *****************************************************************************/
+float levelfromstring ( char *bands , int *bandid )
+{
+    float level = 0 ;
+    locale_t loc = newlocale (LC_NUMERIC_MASK, "C", NULL);
+    locale_t oldloc = uselocale (loc);
+    while( *bandid >= 0 )
+    {
+        level = strtof( bands, &bands);
+        (*bandid)--;
+    }
+    if (loc != (locale_t)0)
+    {
+        uselocale (oldloc);
+        freelocale (loc);
+    }
+    return level;
+}
+float getlevelfromconfig ( intf_thread_t *p_intf , int bandid )
+{
+    char *bands = config_GetPsz( p_intf, "equalizer-bands" );
+    return levelfromstring( bands , &bandid );
+
+}
 static int vlclua_equalizer_get( lua_State *L )
 {
+    int bandid = luaL_checknumber( L, 1 );
+    if ( bandid < 0 || bandid > 9 )
+        return 0;
     input_thread_t *p_input = vlclua_get_input_internal( L );
+    vlc_object_t *p_this = vlclua_get_this( L );
+    intf_thread_t *p_intf = (intf_thread_t *)( p_this );
+    vlc_list_t *list;
+    list = vlc_list_children( p_this );
+    int i;
+    char *bands;
+    float level;
     if( !p_input )
-        return 0;
-
+    {
+        lua_pushnumber ( L, getlevelfromconfig( p_intf, bandid ) );
+        for( i = 0 ; i < list->i_count ; i++ )
+            vlc_object_release( list->p_values[i].p_object );
+        return 1;
+    }
     aout_instance_t *p_aout = input_GetAout( p_input );
     vlc_object_release( p_input );
     if( !p_aout )
-        return 0;
-
-    float level = 0 ;
-    char *psz_af = var_GetNonEmptyString( p_aout, "audio-filter" );
-    if( strstr ( psz_af, "equalizer" ) == NULL )
     {
-        free( psz_af );
-        vlc_object_release( p_aout );
-        return 0;
+        lua_pushnumber ( L, getlevelfromconfig( p_intf, bandid ) );
+        for( i = 0 ; i < list->i_count ; i++ )
+            vlc_object_release( list->p_values[i].p_object );
+        return 1;
     }
-    free( psz_af );
 
-    int bandid = luaL_checknumber( L, 1 );
-    char *psz_bands_origin, *psz_bands;
-    psz_bands_origin = psz_bands = var_GetNonEmptyString( p_aout, "equalizer-bands" );
-    locale_t loc = newlocale (LC_NUMERIC_MASK, "C", NULL);
-    locale_t oldloc = uselocale (loc);
-    while( bandid >= 0 )
+    char *psz_af = var_GetNonEmptyString( p_aout, "audio-filter" );
+    if(psz_af==NULL)
     {
-        level = strtof( psz_bands, &psz_bands);
-        bandid--;
+        vlc_object_release( p_aout );
+        lua_pushnumber ( L, getlevelfromconfig( p_intf, bandid ) );
+        for( i = 0 ; i < list->i_count ; i++ )
+            vlc_object_release( list->p_values[i].p_object );
+        return 1;
     }
-    free( psz_bands_origin );
-    if (loc != (locale_t)0)
+    if( strstr ( psz_af, "equalizer" ) == NULL )
     {
-        uselocale (oldloc);
-        freelocale (loc);
+        free( psz_af );
+        vlc_object_release( p_aout );
+        lua_pushnumber ( L, getlevelfromconfig( p_intf, bandid ) );
+        for( i = 0 ; i < list->i_count ; i++ )
+            vlc_object_release( list->p_values[i].p_object );
+        return 1;
     }
-
-    vlc_object_release( p_aout );
-    if( bandid == -1 )
+    bands = var_GetNonEmptyString( p_aout, "equalizer-bands" );
+    level = levelfromstring( bands , &bandid );
+    if( bandid != -1 )
     {
-        lua_pushnumber( L, level );
+        vlc_object_release( p_aout );
+        lua_pushnumber ( L, getlevelfromconfig( p_intf, bandid ) );
+        for( i = 0 ; i < list->i_count ; i++ )
+            vlc_object_release( list->p_values[i].p_object );
         return 1;
     }
-    else
-        return 0;
+    lua_pushnumber( L, level );
+    vlc_object_release( p_aout );
+    for( i = 0 ; i < list->i_count ; i++ )
+        vlc_object_release( list->p_values[i].p_object );
+    return 1;
 }
 
 
@@ -182,6 +247,9 @@ static int vlclua_equalizer_get( lua_State *L )
 *****************************************************************************/
 static int vlclua_equalizer_set( lua_State *L )
 {
+    int bandid = luaL_checknumber( L, 1 );
+    if ( bandid < 0 || bandid > 9 )
+        return 0;
     input_thread_t *p_input = vlclua_get_input_internal( L );
     if( !p_input )
         return 0;
@@ -193,6 +261,11 @@ static int vlclua_equalizer_set( lua_State *L )
         return 0;
 
     char *psz_af = var_GetNonEmptyString( p_aout, "audio-filter" );
+    if( psz_af==NULL )
+    {
+        vlc_object_release( p_aout );
+        return 0;
+    }
     if( strstr ( psz_af, "equalizer" ) == NULL )
     {
         free( psz_af );
@@ -201,7 +274,6 @@ static int vlclua_equalizer_set( lua_State *L )
     }
     free( psz_af );
 
-    int bandid = luaL_checknumber( L, 1 );
     float level = luaL_checknumber( L, 2 );
     char *bands = var_GetString( p_aout, "equalizer-bands" );
     char newstr[7];
@@ -246,7 +318,7 @@ static int vlclua_equalizer_preset_getpresetname( lua_State *L )
 static int vlclua_equalizer_setpreset( lua_State *L )
 {
     int presetid = luaL_checknumber( L, 1 );
-    if( presetid >= NB_PRESETS )
+    if( presetid < 0 || presetid >= NB_PRESETS )
         return 0;
     input_thread_t *p_input = vlclua_get_input_internal( L );
     if( p_input )
@@ -258,6 +330,11 @@ static int vlclua_equalizer_setpreset( lua_State *L )
             return 0;
         }
         char *psz_af = var_GetNonEmptyString( p_aout, "audio-filter" );
+        if(psz_af==NULL)
+        {
+            vlc_object_release( p_aout );
+            return 0;
+        }
         if ( strstr ( psz_af, "equalizer" ) == NULL )
         {
             vlc_object_release( p_aout );
-- 
1.7.4.1

